@@ -16,7 +16,6 @@
 package org.jbpm.workbench.ht.client.editors.taskdetails;
 
 import java.util.Date;
-
 import javax.annotation.PostConstruct;
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
@@ -25,23 +24,29 @@ import javax.inject.Inject;
 
 import com.google.gwt.user.client.ui.IsWidget;
 import org.jboss.errai.common.client.api.Caller;
-import org.jbpm.workbench.common.client.util.UTCDateBox;
+import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.jbpm.workbench.ht.client.resources.i18n.Constants;
+import org.jbpm.workbench.ht.model.TaskSummary;
 import org.jbpm.workbench.ht.model.events.TaskRefreshedEvent;
 import org.jbpm.workbench.ht.model.events.TaskSelectionEvent;
 import org.jbpm.workbench.ht.service.TaskService;
 
-import static org.jbpm.workbench.common.client.util.TaskUtils.*;
-
 @Dependent
 public class TaskDetailsPresenter {
 
+    @Inject
+    private TranslationService translationService;
+
     @Inject
     protected Event<TaskRefreshedEvent> taskRefreshed;
+
     TaskDetailsView view;
+
     private Constants constants = Constants.INSTANCE;
+
     @Inject
     private Caller<TaskService> taskService;
+
     private long currentTaskId = 0;
 
     private String currentServerTemplateId;
@@ -92,11 +97,7 @@ public class TaskDetailsPresenter {
                                   Long processInstanceId,
                                   String processId) {
         view.setTaskDescription(description);
-        final Long date = UTCDateBox.date2utc(expirationTime);
-        if (date != null) {
-            view.setDueDate(date);
-            view.setDueDateTime(date);
-        }
+        view.setSelectedDate(expirationTime);
         view.setUser(actualOwner);
         view.setTaskStatus(status);
         view.setTaskPriority(priority);
@@ -113,7 +114,6 @@ public class TaskDetailsPresenter {
     public void setReadOnlyTaskDetail() {
         view.setTaskDescriptionEnabled(false);
         view.setDueDateEnabled(false);
-        view.setDueDateTimeEnabled(false);
         view.setTaskPriorityEnabled(false);
         view.setUpdateTaskVisible(false);
     }
@@ -126,7 +126,7 @@ public class TaskDetailsPresenter {
             setReadOnlyTaskDetail();
         }
 
-        setTaskDetails(event.getStatus(),
+        setTaskDetails(translationService.format(event.getStatus()),
                        event.getDescription(),
                        event.getActualOwner(),
                        event.getExpirationTime(),
@@ -135,6 +135,34 @@ public class TaskDetailsPresenter {
                        event.getProcessId());
     }
 
+    public void onTaskRefreshedEvent(@Observes final TaskRefreshedEvent event) {
+        if (currentTaskId == event.getTaskId()) {
+            taskService.call(
+                    (TaskSummary task) -> {
+                        if (task != null) {
+                            setTaskDetails(translationService.format(task.getStatus()),
+                                           task.getDescription(),
+                                           task.getActualOwner(),
+                                           task.getExpirationTime(),
+                                           String.valueOf(task.getPriority()),
+                                           task.getProcessInstanceId(),
+                                           task.getProcessId());
+                        }
+                    },
+                    (message, throwable) -> {
+                        view.displayNotification(constants.TaskDetailsNotAvailableContainerNotStartedOrUnreacheable(event.getDeploymentId()));
+                        return false;
+                    }).getTask(currentServerTemplateId,
+                               currentContainerId,
+                               currentTaskId);
+        }
+    }
+
+    @Inject
+    public void setTranslationService(TranslationService translationService) {
+        this.translationService = translationService;
+    }
+
     public interface TaskDetailsView extends IsWidget {
 
         void init(final TaskDetailsPresenter presenter);
@@ -143,14 +171,10 @@ public class TaskDetailsPresenter {
 
         void setTaskDescriptionEnabled(Boolean enabled);
 
-        void setDueDate(Long date);
+        void setSelectedDate(Date date);
 
         void setDueDateEnabled(Boolean enabled);
 
-        void setDueDateTime(Long time);
-
-        void setDueDateTimeEnabled(Boolean enabled);
-
         void setUser(String user);
 
         void setTaskStatus(String status);
